@@ -978,7 +978,7 @@ def write(file_name, contents='', force=False):
         else:
             raise InvalidFileError('"' + file_name + '" is not a file and cannot be written to. Use argument "force=True" to overwrite.')
     
-    if isinstance(output, bytes):
+    if isinstance(contents, bytes):
         output = contents.decode('utf-8')
     elif not isinstance(contents, str) and isinstance(contents, Iterable):
         output = '\n'.join(contents)
